@@ -1,23 +1,10 @@
 /*
- *  This file is part of the kuiviewer package
- *  Copyright (c) 2003 Richard Moore <rich@kde.org>
- *  Copyright (c) 2003 Ian Reinhart Geiser <geiseri@kde.org>
- *  Copyright (c) 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2003 Richard Moore <rich@kde.org>
+    SPDX-FileCopyrightText: 2003 Ian Reinhart Geiser <geiseri@kde.org>
+    SPDX-FileCopyrightText: 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KUIVIEWERPART_H
 #define KUIVIEWERPART_H
@@ -25,6 +12,7 @@
 #include "kuiviewer_part_interface.h"
 
 // KF
+#include <kparts_version.h>
 #include <KParts/ReadOnlyPart>
 // Qt
 #include <QPointer>
@@ -33,6 +21,7 @@
 #include <QSize>
 
 class KSelectAction;
+class KPluginMetaData;
 class QIODevice;
 class QMdiArea;
 class QMdiSubWindow;
@@ -54,7 +43,11 @@ public:
     /**
      * Default constructor
      */
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    KUIViewerPart(QWidget* parentWidget, QObject* parent, const KPluginMetaData& metaData, const QVariantList& args);
+#else
     KUIViewerPart(QWidget* parentWidget, QObject* parent, const QVariantList& args);
+#endif
 
     /**
      * Destructor
